@@ -32,7 +32,7 @@ static lookups generic[] = {
 	{ "%Y", "3RD_AUTHOR",   PERSON, LEVEL_MAIN },
 	{ "%S", "3RD_TITLE",    SIMPLE, LEVEL_MAIN },
 	{ "%7", "EDITION",      SIMPLE, LEVEL_MAIN },
-	{ "%8", "MONTHDATE",    DATE,   LEVEL_MAIN },
+	{ "%8", "MONTH",    DATE,   LEVEL_MAIN },
 	{ "%9", "GENRE",        SIMPLE, LEVEL_MAIN },
 	{ "%?", "SUB_AUTHOR",   PERSON, LEVEL_MAIN }, /* subsidiary-authors */
 	{ "%!", "SHORTTITLE",   TITLE,  LEVEL_MAIN },
@@ -70,7 +70,7 @@ static lookups journalarticle[] = {
 	{ "%N", "ISSUE",     SIMPLE,   LEVEL_MAIN },
 	{ "%P", "PAGES",     PAGES,    LEVEL_MAIN },
 	{ "%I", "PUBLISHER", SIMPLE,    LEVEL_HOST }, 
-	{ "%8", "PARTMONTHDATE", DATE,     LEVEL_MAIN },
+	{ "%8", "PARTMONTH", DATE,     LEVEL_MAIN },
 	{ "%9", "GENRE",     SIMPLE,  LEVEL_MAIN },
 	{ "%!", "SHORTTITLE",TITLE,    LEVEL_MAIN },
 	{ "%@", "SERIALNUMBER",      SERIALNO, LEVEL_HOST },
@@ -105,7 +105,7 @@ static lookups magazinearticle[] = {
 	{ "%N", "ISSUE",     SIMPLE,  LEVEL_MAIN },
 	{ "%P", "PAGES",     PAGES,   LEVEL_MAIN },
 	{ "%I", "PUBLISHER", SIMPLE,    LEVEL_HOST }, 
-	{ "%8", "PARTMONTHDATE", DATE,    LEVEL_MAIN },
+	{ "%8", "PARTMONTH", DATE,    LEVEL_MAIN },
 	{ "%!", "SHORTTITLE",TITLE,   LEVEL_MAIN },
 	{ "%@", "SERIALNUMBER",      SERIALNO,LEVEL_HOST },
 	{ "%(", "ORIGINALPUB",SIMPLE, LEVEL_MAIN },
@@ -139,7 +139,7 @@ static lookups newspaperarticle[] = {
 	{ "%N", "ISSUE",     SIMPLE,  LEVEL_MAIN },
 	{ "%P", "PAGES",     PAGES,   LEVEL_MAIN },
 	{ "%7", "EDITION",   SIMPLE,  LEVEL_MAIN },
-	{ "%8", "PARTMONTHDATE", DATE,    LEVEL_MAIN },
+	{ "%8", "PARTMONTH", DATE,    LEVEL_MAIN },
 	{ "%!", "SHORTTITLE",TITLE,   LEVEL_MAIN },
 	{ "%@", "SERIALNUMBER",      SERIALNO, LEVEL_MAIN },
 	{ "%(", "ORIGINALPUB",SIMPLE, LEVEL_MAIN },
@@ -172,7 +172,7 @@ static lookups book[] = {
 	{ "%I", "PUBLISHER", SIMPLE,    LEVEL_MAIN }, 
 	{ "%V", "VOLUME" ,   SIMPLE,    LEVEL_MAIN },
 	{ "%6", "NUMVOLUMES",SIMPLE,    LEVEL_MAIN },
-	{ "%P", "NUMBEROFPAGES", SIMPLE,LEVEL_MAIN },
+	{ "%P", "TOTALPAGES", SIMPLE,LEVEL_MAIN },
 	{ "%7", "EDITION",   SIMPLE,    LEVEL_MAIN },
 	{ "%?", "TRANSLATOR",PERSON,    LEVEL_MAIN },
 	{ "%!", "SHORTTITLE",TITLE,     LEVEL_MAIN },
@@ -252,7 +252,7 @@ static lookups editedbook[] = {
 	{ "%I", "PUBLISHER", SIMPLE,    LEVEL_MAIN }, 
 	{ "%V", "VOLUME" ,   SIMPLE,    LEVEL_MAIN },
 	{ "%6", "NUMVOLUMES",SIMPLE,    LEVEL_HOST },
-	{ "%P", "NUMBEROFPAGES", SIMPLE,LEVEL_MAIN },
+	{ "%P", "TOTALPAGES", SIMPLE,LEVEL_MAIN },
 	{ "%7", "EDITION",   SIMPLE,    LEVEL_MAIN },
 	{ "%?", "TRANSLATOR",PERSON,    LEVEL_MAIN },
 	{ "%!", "SHORTTITLE",TITLE,     LEVEL_MAIN },
@@ -289,7 +289,7 @@ static lookups manuscript[] = {
 	{ "%C", "ADDRESS",   SIMPLE,  LEVEL_MAIN },
 	{ "%N", "NUMBER",    SIMPLE,  LEVEL_MAIN },
 	{ "%P", "PAGES",     PAGES,   LEVEL_MAIN },
-	{ "%8", "MONTHDATE", DATE,    LEVEL_MAIN },
+	{ "%8", "MONTH", DATE,    LEVEL_MAIN },
 	{ "%9", "GENRE",     SIMPLE,  LEVEL_MAIN },
 	{ "%!", "SHORTTITLE",TITLE,   LEVEL_MAIN },
 	{ "%M", "ACCESSNUM", SIMPLE,  LEVEL_MAIN },
@@ -321,7 +321,7 @@ static lookups communication[] = {
 	{ "%C", "ADDRESS",   SIMPLE,  LEVEL_MAIN },
 	{ "%V", "VOLUME",    SIMPLE,  LEVEL_MAIN },
 	{ "%I", "PUBLISHER", SIMPLE,  LEVEL_MAIN },
-	{ "%8", "MONTHDATE", DATE,    LEVEL_MAIN },
+	{ "%8", "MONTH", DATE,    LEVEL_MAIN },
 	{ "%9", "GENRE",     SIMPLE,  LEVEL_MAIN },
 	{ "%!", "SHORTTITLE",TITLE,   LEVEL_MAIN },
 	{ "%M", "ACCESSNUM", SIMPLE,  LEVEL_MAIN },
@@ -349,7 +349,7 @@ static lookups proceedings[] = {
 	{ "%D", "YEAR",      SIMPLE,  LEVEL_HOST },
 	{ "%T", "TITLE" ,    TITLE,   LEVEL_MAIN },
 	{ "%E", "EDITOR",    PERSON,  LEVEL_MAIN },
-	{ "%B", "CONFERENCE_NAME", SIMPLE,  LEVEL_MAIN }, 
+	{ "%B", "TITLE",     SIMPLE,  LEVEL_HOST }, 
 	{ "%C", "ADDRESS",   SIMPLE,  LEVEL_MAIN },
 	{ "%I", "PUBLISHER", SIMPLE,  LEVEL_MAIN }, 
 	{ "%V", "VOLUME" ,   SIMPLE,  LEVEL_MAIN },
@@ -357,9 +357,9 @@ static lookups proceedings[] = {
 	{ "%N", "NUMBER",    SIMPLE,  LEVEL_MAIN },
 	{ "%P", "PAGES",     PAGES,   LEVEL_MAIN },
 	{ "%Y", "EDITOR",    PERSON,  LEVEL_HOST }, /* SERIES_EDITOR */
-	{ "%S", "TITLE",     TITLE,   LEVEL_HOST }, /* SERIES_TITLE */
+	{ "%S", "TITLE",     TITLE,   LEVEL_HOST+1 }, /* SERIES_TITLE */
 	{ "%7", "EDITION",   SIMPLE,  LEVEL_HOST },
-	{ "%8", "MONTHDATE", DATE,    LEVEL_MAIN },
+	{ "%8", "MONTH", DATE,    LEVEL_MAIN },
 	{ "%!", "SHORTTITLE",TITLE,   LEVEL_MAIN },
 	{ "%1", "CUSTOM1",   SIMPLE,  LEVEL_MAIN },
 	{ "%2", "CUSTOM2",   SIMPLE,  LEVEL_MAIN },
@@ -393,7 +393,7 @@ static lookups thesis[] = {
 	{ "%P", "NUMPAGES",     PAGES    , LEVEL_MAIN },
 /*	{ "%9", "THESIS_TYPE", SIMPLE   , LEVEL_MAIN },*/
 	{ "%9", "GENRE",     SIMPLE   , LEVEL_MAIN }, /* thesis type */
-	{ "%8", "MONTHDATE", DATE     , LEVEL_MAIN },
+	{ "%8", "MONTH", DATE     , LEVEL_MAIN },
 	{ "%!", "SHORTTITLE",TITLE    , LEVEL_MAIN },
 	{ "%1", "CUSTOM1",   SIMPLE   , LEVEL_MAIN },
 	{ "%2", "CUSTOM2",   SIMPLE   , LEVEL_MAIN },
@@ -454,7 +454,7 @@ static lookups audiovisual[] = {
 	{ "%I", "PUBLISHER", SIMPLE   , LEVEL_MAIN },
 	{ "%V", "EXTENTOFWORK",     SIMPLE   , LEVEL_MAIN },
 	{ "%N", "NUMBER",    SIMPLE   , LEVEL_MAIN },
-	{ "%8", "MONTHDATE", DATE     , LEVEL_MAIN },
+	{ "%8", "MONTH", DATE     , LEVEL_MAIN },
 	{ "%9", "GENRE",     SIMPLE   , LEVEL_MAIN },
 	{ "%?", "PERFORMER", PERSON   , LEVEL_MAIN },
 	{ "%!", "SHORTTITLE",TITLE    , LEVEL_MAIN },
@@ -487,7 +487,7 @@ static lookups broadcast[] = {
 	{ "%C", "ADDRESS",   SIMPLE   , LEVEL_MAIN },
 	{ "%I", "PUBLISHER", SIMPLE   , LEVEL_MAIN },
 	{ "%Y", "PRODUCER",  PERSON   , LEVEL_MAIN },
-	{ "%8", "MONTHDATE", DATE     , LEVEL_MAIN },
+	{ "%8", "MONTH", DATE     , LEVEL_MAIN },
 	{ "%9", "GENRE",     SIMPLE   , LEVEL_MAIN },
 	{ "%!", "SHORTTITLE",TITLE    , LEVEL_MAIN },
 	{ "%@", "SERIALNUMBER",      SERIALNO , LEVEL_MAIN },
@@ -552,7 +552,7 @@ static lookups artwork[] = {
 	{ "%T", "TITLE" ,    TITLE    , LEVEL_MAIN },
 	{ "%C", "ADDRESS",   SIMPLE   , LEVEL_MAIN },
 	{ "%I", "PUBLISHER", SIMPLE   , LEVEL_MAIN },
-	{ "%8", "MONTHDATE", DATE     , LEVEL_MAIN },
+	{ "%8", "MONTH", DATE     , LEVEL_MAIN },
 	{ "%9", "GENRE",     SIMPLE   , LEVEL_MAIN },
 	{ "%!", "SHORTTITLE",TITLE    , LEVEL_MAIN },
 	{ "%M", "ACCESSNUM", SIMPLE   , LEVEL_MAIN },
@@ -582,7 +582,7 @@ static lookups report[] = {
 	{ "%C", "ADDRESS",   SIMPLE   , LEVEL_MAIN },
 	{ "%I", "PUBLISHER", SIMPLE   , LEVEL_MAIN },
 	{ "%P", "PAGES",     PAGES    , LEVEL_MAIN },
-	{ "%8", "MONTHDATE", DATE     , LEVEL_MAIN },
+	{ "%8", "MONTH", DATE     , LEVEL_MAIN },
 	{ "%9", "GENRE",     SIMPLE   , LEVEL_MAIN },
 	{ "%@", "SERIALNUMBER", SERIALNO , LEVEL_MAIN },
 	{ "%!", "SHORTTITLE",TITLE    , LEVEL_MAIN },
@@ -680,7 +680,7 @@ static lookups hearing[] = {
 	{ "%P", "NUMPAGES",  PAGES,  LEVEL_MAIN  },
 	{ "%S", "LEGISLATIVEBODY", SIMPLE, LEVEL_MAIN  },
 	{ "%7", "SESSION",   SIMPLE, LEVEL_MAIN  },
-	{ "%8", "MONTHDATE", DATE,   LEVEL_MAIN  },
+	{ "%8", "MONTH", DATE,   LEVEL_MAIN  },
 	{ "%!", "SHORTTITLE",TITLE,  LEVEL_MAIN  },
 	{ "%(", "ORIGINALPUB",SIMPLE, LEVEL_MAIN },
 	{ "%M", "ACCESSNUM", SIMPLE, LEVEL_MAIN  },
@@ -713,7 +713,7 @@ static lookups bill[] = {
 	{ "%&", "CODESECTION",SIMPLE, LEVEL_MAIN  },
 	{ "%S", "LEGISLATIVEBODY", SIMPLE, LEVEL_MAIN  },
 	{ "%7", "SESSION",   SIMPLE, LEVEL_MAIN  },
-	{ "%8", "MONTHDATE", DATE, LEVEL_MAIN    },
+	{ "%8", "MONTH", DATE, LEVEL_MAIN    },
 	{ "%?", "SPONSOR",   PERSON, LEVEL_MAIN  },
 	{ "%!", "SHORTTITLE",TITLE,  LEVEL_MAIN   },
 	{ "%(", "ORIGINALPUB",SIMPLE, LEVEL_MAIN  },
@@ -746,7 +746,7 @@ static lookups statute[] = {
 	{ "%P", "PAGES",     PAGES, LEVEL_MAIN    },
 	{ "%&", "SECTION",   SIMPLE, LEVEL_MAIN  },
 	{ "%7", "SESSION",   SIMPLE, LEVEL_MAIN  },
-	{ "%8", "MONTHDATE", DATE, LEVEL_MAIN    },
+	{ "%8", "MONTH", DATE, LEVEL_MAIN    },
 	{ "%!", "SHORTTITLE",TITLE,  LEVEL_MAIN   },
 	{ "%(", "ORIGINALPUB",SIMPLE, LEVEL_MAIN  },
 	{ "%M", "ACCESSNUM", SIMPLE, LEVEL_MAIN  },
@@ -778,7 +778,7 @@ static lookups lawcase[] = {
 	{ "%V", "VOLUME",    SIMPLE, LEVEL_MAIN   },
 	{ "%N", "PUBLICLAWNUMBER",    SIMPLE, LEVEL_MAIN  },
 	{ "%P", "STARTPAGE",     SIMPLE, LEVEL_MAIN  },
-	{ "%8", "MONTHDATE", DATE, LEVEL_MAIN    },
+	{ "%8", "MONTH", DATE, LEVEL_MAIN    },
 	{ "%?", "COUNSEL",   PERSON, LEVEL_MAIN  },
 	{ "%!", "SHORTTITLE",TITLE,  LEVEL_MAIN   },
 	{ "%(", "ORIGINALPUB",SIMPLE, LEVEL_MAIN  },
@@ -801,6 +801,53 @@ static lookups lawcase[] = {
 	{ "  ", "GENRE|legal case and case notes", ALWAYS, LEVEL_MAIN }
 };
 
+static lookups chart[] = {
+	{ "%0", "TYPE",      TYPE,   LEVEL_MAIN },
+	{ "%A", "AUTHOR",    PERSON, LEVEL_MAIN },
+	{ "%D", "YEAR",      SIMPLE, LEVEL_MAIN },
+	{ "%T", "TITLE" ,    TITLE,  LEVEL_MAIN },
+	{ "%J", "TITLE",     TITLE,  LEVEL_HOST }, /* for refer formats */
+	{ "%E", "2ND_AUTHOR",PERSON, LEVEL_MAIN },
+	{ "%B", "2ND_TITLE", SIMPLE, LEVEL_MAIN },
+	{ "%C", "ADDRESS",   SIMPLE, LEVEL_MAIN },
+	{ "%I", "PUBLISHER", SIMPLE, LEVEL_MAIN }, 
+	{ "%V", "VOLUME" ,   SIMPLE, LEVEL_MAIN },
+	{ "%6", "NUMVOLUMES",SIMPLE, LEVEL_HOST },
+	{ "%N", "NUMBER",    SIMPLE, LEVEL_MAIN },
+	{ "%P", "PAGES",        PAGES,  LEVEL_MAIN },
+	{ "%&", "SECTION",      SIMPLE, LEVEL_MAIN },
+	{ "%Y", "3RD_AUTHOR",   PERSON, LEVEL_MAIN },
+	{ "%S", "3RD_TITLE",    SIMPLE, LEVEL_MAIN },
+	{ "%7", "EDITION",      SIMPLE, LEVEL_MAIN },
+	{ "%8", "MONTH",    DATE,   LEVEL_MAIN },
+	{ "%9", "GENRE",        SIMPLE, LEVEL_MAIN },
+	{ "%?", "SUB_AUTHOR",   PERSON, LEVEL_MAIN }, /* subsidiary-authors */
+	{ "%!", "SHORTTITLE",   TITLE,  LEVEL_MAIN },
+	{ "%@", "SERIALNUM", SERIALNO,  LEVEL_MAIN },
+	{ "%(", "ORIGINALPUB",  SIMPLE, LEVEL_MAIN },
+	{ "%)", "REPRINTEDITION",SIMPLE,LEVEL_MAIN },
+	{ "%*", "REVIEWEDITEM", SIMPLE, LEVEL_MAIN },
+	{ "%1", "CUSTOM1",      SIMPLE, LEVEL_MAIN },
+	{ "%2", "CUSTOM2",      SIMPLE, LEVEL_MAIN },
+	{ "%3", "CUSTOM3",      SIMPLE, LEVEL_MAIN },
+	{ "%4", "CUSTOM4",      SIMPLE, LEVEL_MAIN },
+	{ "%#", "CUSTOM5",      SIMPLE, LEVEL_MAIN },
+	{ "%$", "CUSTOM6",      SIMPLE, LEVEL_MAIN },
+	{ "%M", "ACCESSNUM",    SIMPLE, LEVEL_MAIN },
+	{ "%L", "CALLNUMBER",   SIMPLE, LEVEL_MAIN },
+	{ "%F", "REFNUM",       SIMPLE, LEVEL_MAIN },
+	{ "%K", "KEYWORD",      SIMPLE, LEVEL_MAIN }, 
+	{ "%X", "ABSTRACT",     SIMPLE, LEVEL_MAIN },
+	{ "%O", "NOTES",        SIMPLE, LEVEL_MAIN },
+	{ "%U", "URL",          SIMPLE, LEVEL_MAIN },
+	{ "%Z", "NOTES",        SIMPLE, LEVEL_MAIN },
+	{ "%W", "PHYSICALLOC",  SIMPLE, LEVEL_MAIN },  /* physical location */
+	{ "%+", "AUTHORADDRESS",SIMPLE, LEVEL_MAIN },
+	{ "  ", "GENRE|chart",  ALWAYS, LEVEL_MAIN }
+};
+
+
+
 /* order is important....."Book" matches "Book" and "Book Section", hence
  * "Book Section must come first */
 
@@ -827,13 +874,14 @@ variants end_all[] = {
 	{"Hearing", &(hearing[0]), sizeof(hearing)/sizeof(lookups)},
 	{"Bill", &(bill[0]), sizeof(bill)/sizeof(lookups)},
 	{"Statute", &(statute[0]), sizeof(statute)/sizeof(lookups)},
-	{"Case", &(lawcase[0]), sizeof(lawcase)/sizeof(lookups)}
+	{"Case", &(lawcase[0]), sizeof(lawcase)/sizeof(lookups)},
+	{"Chart or Table", &(chart[0]), sizeof(chart)/sizeof(lookups)}
 };
 
 
 int end_nall = sizeof( end_all ) / sizeof( variants );
 
-#ifdef NOCOMPILE
+#if 0
 int
 get_reftype( char *p, long refnum )
 {
