@@ -11,6 +11,7 @@ class Linker {
 	public:
 	virtual bool canLink (Document const *doc) {return false;};
 	virtual void doLink (Document *doc);
+	virtual Glib::ustring getURL (Document *doc);
 	virtual Glib::ustring getLabel () {return Glib::ustring();};
 	virtual Glib::ustring getName () = 0;
 
@@ -24,7 +25,7 @@ class Linker {
 class DoiLinker : public Linker {
 	public:
 	bool canLink (Document const *doc);
-	void doLink (Document *doc);
+	virtual Glib::ustring getURL (Document *doc);
 	virtual Glib::ustring getName () {return "doi";}
 	Glib::ustring getLabel ();
 };
@@ -32,7 +33,7 @@ class DoiLinker : public Linker {
 class ArxivLinker : public Linker {
 	public:
 	bool canLink (Document const *doc);
-	void doLink (Document *doc);
+	virtual Glib::ustring getURL (Document *doc);
 	virtual Glib::ustring getName () {return "arxiv";}
 	Glib::ustring getLabel ();
 };
@@ -41,7 +42,7 @@ class ArxivLinker : public Linker {
 class UrlLinker : public Linker {
 	public:
 	bool canLink (Document const *doc);
-	void doLink (Document *doc);
+	virtual Glib::ustring getURL (Document *doc);
 	virtual Glib::ustring getName () {return "url";}
 	Glib::ustring getLabel ();
 };
@@ -50,7 +51,7 @@ class UrlLinker : public Linker {
 class PubmedLinker : public Linker {
 	public:
 	bool canLink (Document const *doc);
-	void doLink (Document *doc);
+	virtual Glib::ustring getURL (Document *doc);
 	virtual Glib::ustring getName () {return "pubmed";}
 	Glib::ustring getLabel ();
 };
@@ -59,7 +60,7 @@ class PubmedLinker : public Linker {
 class GoogleLinker : public Linker {
 	public:
 	bool canLink (Document const *doc);
-	void doLink (Document *doc);
+	virtual Glib::ustring getURL (Document *doc);
 	virtual Glib::ustring getName () {return "google";}
 	Glib::ustring getLabel ();
 };
