@@ -17,7 +17,6 @@
 #include <map>
 
 #include <gtkmm.h>
-#include <libglademm.h>
 
 #include "Plugin.h"
 
@@ -173,6 +172,7 @@ class RefWindow {
 		void onAddDocFilesCancel       (Gtk::Button *button, Gtk::ProgressBar *progress);
 		bool cancelAddDocFiles_;
 		void onAddDocFilesTag          (std::vector<Document*> &docs);
+		void configureDocumentFileChooser(Gtk::FileChooserDialog & chooser);
 
 		class TaggerDialog : public Gtk::Dialog {
 			Gtk::TreeModelColumn<Glib::ustring> nameColumn_;
@@ -216,7 +216,7 @@ class RefWindow {
 			void updateSensitivity ();
 			void resultActivated (const Gtk::TreePath &path, Gtk::TreeViewColumn * col);
 
-			Glib::RefPtr<Gnome::Glade::Xml> xml_;
+			Glib::RefPtr<Gtk::Builder> xml_;
 
 			Gtk::Dialog *dialog_;
 			Gtk::Button *searchButton_;
