@@ -11,17 +11,23 @@ class Document;
 
 class ThumbnailGenerator
 {
-	Glib::Mutex taskLock_;
 	std::multimap<Glib::ustring, Document *> taskList_;
+	Glib::ustring currentFile_;
+	Glib::RefPtr<Gio::File> currentUri_;
+	Glib::RefPtr<Gio::File> thumbnail_file_;
 
 	static Glib::RefPtr<Gdk::Pixbuf> defaultthumb_;
 	static Glib::RefPtr<Gdk::Pixbuf> thumbframe_;
 
-	void mainLoop ();
 	Glib::RefPtr<Gdk::Pixbuf> lookupThumb (Glib::ustring const &file);
+	void lookupThumb_async (Glib::ustring const &file);
+	void _onQueryInfoAsyncReady(Glib::RefPtr<Gio::AsyncResult>& result);
+	void _setDocumentThumbnail(Glib::RefPtr<Gdk::Pixbuf>& result);
+	void _taskDone();
+	void _taskAbort();
 
 	ThumbnailGenerator ();
-	void run ();
+	bool run ();
 
 	public:
 	void registerRequest (Glib::ustring const &file, Document *doc);
